.. _executor_index:

Executor
========

libEnsemble's Executor can be used within the simulator (and, potentially, the generator)
functions to provide a simple, portable interface for running and managing user
applications.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: libEnsemble Executor:

   overview
   executor
